@@ -28,7 +28,7 @@ class TemplateBackend:
         else:
             raise ImproperlyConfigured('You need to provide POSTAGEAPP_API_KEY or EMAIL_POSTAGEAPP_API_KEY in your Django settings file') 
 
-    def send(self, template_name, from_email, recipient_list, context, cc=[], bcc=[], fail_silently=False, headers={}):
+    def send(self, template_name, from_email, recipient_list, context, cc=[], bcc=[], fail_silently=False, headers={}, **kwargs):
         if cc != [] or bcc != []:
             raise HeaderNotSupportedException("PostageApp doesn't currently support CC, or BCC")
         try:
